@@ -19,8 +19,8 @@ from .category import NotifyCategory
 from .choices import TYPE, STATE
 from .file import NotifyFile
 from .template import NotifyTemplate
-from ..exceptions import TemplatesNotExists, IsInstanceException
-from ..mixins import UserNotifyMixin, NotifyMethodsMixin
+from ..exceptions import IsInstanceException
+from ..mixins import UserNotifyMixin
 from ..utils.send_data import SendData
 
 from ..clients import SMSClient, EmailClient, CallClient, TelegramClient, ViberClient, PushClient, WhatsAppClient
@@ -30,7 +30,7 @@ NotifyMixin = import_string(getattr(settings, 'GARPIX_NOTIFY_MIXIN', 'garpix_not
 User = get_user_model()
 
 
-class Notify(NotifyMixin, UserNotifyMixin, NotifyMethodsMixin):
+class Notify(NotifyMixin, UserNotifyMixin):
     """
     Уведомление
     """
@@ -75,7 +75,7 @@ class Notify(NotifyMixin, UserNotifyMixin, NotifyMethodsMixin):
             self.viber_chat_id = self.user.viber_chat_id if self.user.viber_chat_id else self.viber_chat_id
 
         if self.phone is not None:
-            self.phone = re.sub("[^0-9]", "", self.phone)
+            self.phone = re.sub(r"\D", "", self.phone)
 
     def start_send(self):  # noqa
 
@@ -134,9 +134,6 @@ class Notify(NotifyMixin, UserNotifyMixin, NotifyMethodsMixin):
                 .filter(event=event, is_active=True)
             )
 
-        if not templates.exists():
-            raise TemplatesNotExists()
-
         file_instances = []
         if files:
             file_instances = list(map(lambda file: NotifyFile.objects.create(file=file), files))
